/* Example code based on http://www.stata-journal.com/sjpdf.html?articlenum=dm0029
Created by: Mark Bruyneel, 24 April 2017
The example script below provides the tenure of the auditor for a company for the year 2008 */
clear all // Empty memory
import excel "I:\AuditorTestfile.xlsx", sheet("Blad1") firstrow // Import test file. Remember to change the driveletter and path if needed !!!
xtset companynr fiscalyear // Tells Stata that this is panel data
gen begin=auditorid!=L.auditorid // Generate a new variable and start a new count of 1 if the auditor is not the same as in the previous record
replace begin=1 if fiscalyear==1999 // This action is to ensure that each first company record for 1999 starts with 1 for the first Auditor
bysort companynr: gen changes=sum(begin) // Identifies auditor changes
by companynr: egen lastauditor=max(changes) // Identifies the last auditor
by companynr: egen latenure=total(changes==lastauditor) // This gives the tenure of the last auditor

// Optional: Dummy variable if auditor is BigFour
gen bigfour=0 // Generate Dummy for Big Four
replace bigfour=1 if auditorid==1 // PWC = Big Four
replace bigfour=1 if auditorid==2 // EY = Big Four
replace bigfour=1 if auditorid==3 // Deloitte = Big Four
replace bigfour=1 if auditorid==4 // KPMG = Big Four

// Optional remove duplicate data if the auditor tenure needed is only for the last year = 2008
drop auditorid-lastauditor // Remove superfluous variables
drop if fiscalyear <=2007 // Removes all years except the relevant year 2008

bro // Look at the data
